%define git_url git://git.fedorahosted.org/chkconfig.git

Summary:	A system tool for maintaining the /etc/rc*.d hierarchy
Name:		chkconfig
Version:	1.25
Release:	%mkrel 2
License:	GPL-2.0-only
Group:		System/Boot and Init
Url:		https://github.com/fedora-sysv/chkconfig
# TODO: fix Source0 url
Source0:	https://github.com/fedora-sysv/chkconfig/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:	chkconfig.po
# (cg) Revert the selinux stuff for now.
Patch0500: 0500-Revert-leveldb-remove-debug-output.patch
Patch0501: 0501-Revert-leveldb-restore-selinux-context-for-xinetd-co.patch
Patch0502: 0502-Revert-Makefile-fix-wrongly-behaving-LDFLAGS.patch

# Downstream patches
Patch0900: 0900-netsysv-Use-Mandriva-colours.patch
Patch0901: 0901-leveldb-Change-runlevels-dir-to-suit-Mandriva.patch
Patch0902: 0902-chkconfig-Delete-a-service-before-adding-it.patch
Patch0903: 0903-chkconfig-Support-adding-deleting-xinetd-services.patch
Patch0904: 0904-chkconfig-Do-not-show-errors-in-service-lists.patch
Patch0905: 0905-chkconfig-Skip-any-init-script-with-a-dot-comma-or-t.patch
Patch0906: 0906-chkconfig-Fix-xinetd-error-message.patch
Patch0907: 0907-chkconfig-Fix-priority-when-adding-a-LSB-service-req.patch

BuildRequires:	gettext
BuildRequires:	pkgconfig(libnewt)
BuildRequires:	pkgconfig(popt)
BuildRequires:	pkgconfig(libsystemd)
BuildRequires:	slang
Conflicts:	rpm-helper < 0.6
Conflicts:	systemd-units < 221
Provides:	/sbin/chkconfig
Provides:	/usr/sbin/chkconfig
Provides:	/sbin/update-alternatives
Provides:	/usr/sbin/update-alternatives
Provides:	alternatives = %{version}-%{release}
Provides:	update-alternatives = 1.18.1-1
Obsoletes:	update-alternatives < 1.9.0-17

%description
Chkconfig is a basic system utility.  It updates and queries runlevel
information for system services.  Chkconfig manipulates the numerous
symbolic links in /etc/rc*.d, to relieve system administrators of some
of the drudgery of manually editing the symbolic links.

%package -n	ntsysv
Summary:	A system tool for maintaining the /etc/rc*.d hierarchy
Group:		System/Boot and Init
Requires:	chkconfig

%description -n	ntsysv
ntsysv updates and queries runlevel information for system services.
ntsysv relieves system administrators of having to directly manipulate
the numerous symbolic links in /etc/rc*.d.

%prep
%setup -q
#patch0501 -p1 -b .OR
%autopatch -p1
perl -pi -e 's/\bmv\b/mv -f/' po/Makefile

%build

%ifarch sparc
LIBMHACK=-lm
%endif

%make_build RPM_OPT_FLAGS="%{optflags}" LIBMHACK=$LIBMHACK LDFLAGS="%{ldflags}"

%install
%make_install MANDIR=%{_mandir} BINDIR=%{_sbindir}

mkdir -p %{buildroot}%{_sysconfdir}/rc.d/init.d
for n in 0 1 2 3 4 5 6 7; do
    mkdir -p %{buildroot}%{_sysconfdir}/rc.d/rc${n}.d
done

cd %{buildroot}%{_sysconfdir}/
ln -s rc.d/init.d init.d
cd -
ln -s rc7.d %{buildroot}%{_sysconfdir}/rc.d/rcS.d

# corrected indonesian language code (it has changed from 'in' to 'id')
mkdir -p %{buildroot}%{_datadir}/locale/id/LC_MESSAGES
mv %{buildroot}%{_datadir}/locale/{in,in_ID}/LC_MESSAGES/* \
	%{buildroot}%{_datadir}/locale/id/LC_MESSAGES || :
rm -rf %{buildroot}%{_datadir}/locale/{in,in_ID} || :

mkdir -p %{buildroot}%{_datadir}/locale/zh_TW.Big5/LC_MESSAGES
msgfmt %SOURCE1 -o %{buildroot}%{_datadir}/locale/zh_TW.Big5/LC_MESSAGES/chkconfig.mo

# Geoff 20020623 -- zh is incorrect for locale and there's nothing in it anyway
rm -fr %{buildroot}%_datadir/locale/zh

%find_lang %{name}


%pretrans -p <lua>
path = "%{_localstatedir}/lib/alternatives"
path2 = "%{_localstatedir}/lib/rpm/alternatives"
st = posix.stat(path)
st2 = posix.stat(path2)
if st and st.type == "link" and st2 and st2.type == "directory" then
  os.remove(path)
  os.rename(path2, path)
  posix.symlink(path, path2)
end

%files -f %{name}.lang
%{_sbindir}/chkconfig
%{_prefix}/lib/systemd/systemd-sysv-install
%{_mandir}/man8/chkconfig.8*
%dir %{_sysconfdir}/rc.d
%dir %{_sysconfdir}/rc.d/init.d
%dir %{_sysconfdir}/rc.d/rc[0-7]*
%{_sysconfdir}/rc.d/rcS.d
%{_sysconfdir}/init.d
%{_sbindir}/alternatives
%{_sbindir}/update-alternatives
%{_mandir}/man8/alternatives.8*
%{_mandir}/man8/update-alternatives.8*
%ghost %{_localstatedir}/lib/rpm/alternatives
%dir %{_localstatedir}/lib/alternatives
%dir %{_sysconfdir}/alternatives

%files -n ntsysv
%{_sbindir}/ntsysv
%{_mandir}/man8/ntsysv.8*


%changelog
* Fri Apr 05 2024 wally <wally> 1.25-2.mga10
+ Revision: 2054654
- basesystem rebuild for i686

* Sun Oct 22 2023 daviddavid <daviddavid> 1.25-1.mga10
+ Revision: 2000218
- new version: 1.25
+ luigiwalser <luigiwalser>
- 1.22

* Tue Oct 11 2022 luigiwalser <luigiwalser> 1.21-1.mga9
+ Revision: 1896319
- 1.21

* Thu Mar 24 2022 umeabot <umeabot> 1.19-2.mga9
+ Revision: 1824451
- Mageia 9 Mass Rebuild

* Wed Aug 04 2021 luigiwalser <luigiwalser> 1.19-1.mga9
+ Revision: 1739355
- 1.19

* Tue Mar 02 2021 daviddavid <daviddavid> 1.15-1.mga9
+ Revision: 1695945
- new version: 1.15

* Fri Oct 09 2020 shlomif <shlomif> 1.14-1.mga8
+ Revision: 1632983
- New version 1.14

* Sat Feb 15 2020 umeabot <umeabot> 1.11-3.mga8
+ Revision: 1526666
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Thu Jun 20 2019 tmb <tmb> 1.11-2.mga7
+ Revision: 1400404
- create alternatives symlink in lua pretrans and add it as ghost
+ ngompa <ngompa>
- Drop /var/lib/rpm/alternatives symlink as it breaks rpm --rebuilddb

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1.11-1.mga7
+ Revision: 1346305
- 1.11
- rediff all patches
- add "alternatives" as virtual provides

* Sat Dec 01 2018 wally <wally> 1.10-3.mga7
+ Revision: 1337117
- move alternatives to /usr/lib/alternatives and create /usr/lib/rpm/alternatives as a symlink

* Sat Sep 22 2018 umeabot <umeabot> 1.10-2.mga7
+ Revision: 1296121
- Mageia 7 Mass Rebuild

* Wed Aug 23 2017 ovitters <ovitters> 1.10-1.mga7
+ Revision: 1144097
+ rebuild (emptylog)

* Sat Apr 29 2017 luigiwalser <luigiwalser> 1.10-1.mga6
+ Revision: 1097991
- 1.10
+ wally <wally>
- fix URL

* Thu Jul 28 2016 luigiwalser <luigiwalser> 1.8-1.mga6
+ Revision: 1043852
- add some file provides
- 1.8
- rediff patch 0501

* Fri Jan 29 2016 luigiwalser <luigiwalser> 1.7-4.mga6
+ Revision: 928605
- bump release tag and provide update-alternatives version 1.18.1

* Thu Jan 28 2016 luigiwalser <luigiwalser> 1.7-3.mga6
+ Revision: 928295
- provide update-alternatives

* Thu Jan 28 2016 luigiwalser <luigiwalser> 1.7-2.mga6
+ Revision: 928288
- use chkconfig implementation of update-alternatives

* Thu Dec 17 2015 shlomif <shlomif> 1.7-1.mga6
+ Revision: 911295
- New version 1.7

* Thu Oct 08 2015 colin <colin> 1.6-1.mga6
+ Revision: 887370
- New version: 1.6

* Fri Aug 21 2015 tmb <tmb> 1.5-3.mga6
+ Revision: 867415
- rebuild for new gcc

* Thu Jun 25 2015 colin <colin> 1.5-2.mga6
+ Revision: 842886
- Add conflicts with too old systemd-units for smooth upgrades

* Wed Jun 24 2015 colin <colin> 1.5-1.mga6
+ Revision: 842309
- New version: 1.5
- Rediff patches
- Drop runlevel 7 patch (no longer needed)
- Drop --no-reload patch for systemd (newer systemd does not need this)
- Document patches better (some might be droppable/upstreamable)

* Thu Nov 20 2014 luigiwalser <luigiwalser> 1.3.63-1.mga5
+ Revision: 797959
- 1.3.63

* Wed Oct 15 2014 umeabot <umeabot> 1.3.62-3.mga5
+ Revision: 748324
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3.62-2.mga5
+ Revision: 678379
- Mageia 5 Mass Rebuild

* Fri Aug 15 2014 luigiwalser <luigiwalser> 1.3.62-1.mga5
+ Revision: 662887
- 1.3.62

* Mon Jan 13 2014 colin <colin> 1.3.61-3.mga4
+ Revision: 566487
- Add a --no-reload option to chkconfig to disable systemd daemon-reload (mga#12278)

* Sat Oct 19 2013 umeabot <umeabot> 1.3.61-2.mga4
+ Revision: 533774
- Mageia 4 Mass Rebuild

* Thu Sep 05 2013 luigiwalser <luigiwalser> 1.3.61-1.mga4
+ Revision: 475269
- 1.3.61

* Sat Mar 16 2013 luigiwalser <luigiwalser> 1.3.60-1.mga3
+ Revision: 403502
- chkconfig should own /etc/rc.d (rhbz#894328)
- 1.3.60
- rediff patch 5
- remove upstreamed ldflags patch

* Wed Jan 23 2013 fwang <fwang> 1.3.59-5.mga3
+ Revision: 391233
- add virtual provides

* Wed Jan 23 2013 fwang <fwang> 1.3.59-4.mga3
+ Revision: 391170
- update rpm group
- update rpm group

* Fri Jan 11 2013 umeabot <umeabot> 1.3.59-3.mga3
+ Revision: 347677
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jul 29 2012 luigiwalser <luigiwalser> 1.3.59-2.mga3
+ Revision: 275715
- add upstream patch to use correct ldflags

* Sun Jul 29 2012 luigiwalser <luigiwalser> 1.3.59-1.mga3
+ Revision: 275714
- 1.3.59
- rediff patches 6, 13, and 15

* Thu Sep 08 2011 tv <tv> 1.3.51-1.mga2
+ Revision: 141499
- new release, more systemd friendly
- sync with mdv:
- drop P11, 12, 14 - upstream (some with different implementation)
- rediff P1, 5, 6, 7, 8, 13, 15
+ kharec <kharec>
- imported package chkconfig
+ tmb <tmb>
- imported package chkconfig
- imported package chkconfig
- imported package chkconfig


* Tue Nov 30 2010 Oden Eriksson <oeriksson@mandriva.com> 1.3.37-6mdv2011.0
+ Revision: 603828
- rebuild

* Sat Nov 28 2009 Andrey Borzenkov <arvidjaar@mandriva.org> 1.3.37-5mdv2010.1
+ Revision: 470792
- fix patch14 (was Required-Stop instead of Should-Stop)

* Sun Aug 09 2009 Oden Eriksson <oeriksson@mandriva.com> 1.3.37-4mdv2010.0
+ Revision: 413234
- rebuild

* Thu Feb 05 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.37-3mdv2009.1
+ Revision: 337821
-Patch15: add runlevel 7, acting as runlevel S
- Add git url

* Thu Dec 25 2008 Oden Eriksson <oeriksson@mandriva.com> 1.3.37-2mdv2009.1
+ Revision: 318468
- rediffed some fuzzy patches
- use %%ldflags

* Mon Sep 01 2008 Olivier Blin <oblin@mandriva.com> 1.3.37-1mdv2009.0
+ Revision: 278275
- rediff lsb patch
- 1.3.37

* Mon Jun 16 2008 Thierry Vignaud <tv@mandriva.org> 1.3.34-6mdv2009.0
+ Revision: 220567
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.3.34-5mdv2008.1
+ Revision: 136304
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Aug 30 2007 Olivier Blin <oblin@mandriva.com> 1.3.34-5mdv2008.0
+ Revision: 75648
- initialize dependencies list string (fix corruption, #32958)

* Thu May 31 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 1.3.34-4mdv2008.0
+ Revision: 33301
- Rebuild with libnewt0.52.

* Wed May 02 2007 Olivier Blin <oblin@mandriva.com> 1.3.34-3mdv2008.0
+ Revision: 20731
- fix build in interactive terminal (#30598)

* Mon Apr 30 2007 Pixel <pixel@mandriva.com> 1.3.34-2mdv2008.0
+ Revision: 19550
- explicit file provide /sbin/chkconfig

* Thu Apr 19 2007 Olivier Blin <oblin@mandriva.com> 1.3.34-1mdv2008.0
+ Revision: 14998
- 1.3.34


* Sun Jan 21 2007 Olivier Blin <oblin@mandriva.com> 1.3.30-4mdv2007.0
+ Revision: 111339
- restore LSB patch but make it non-fatal (to allow services to be uninstalled)

* Sat Jan 20 2007 Olivier Blin <oblin@mandriva.com> 1.3.30-3mdv2007.1
+ Revision: 111145
- do not check for Required-Start and Required-Stop dependencies, the LSB spec does not impose they are satisfied (fixes #24409 as a brutal side-effect)

* Sat Jan 20 2007 Olivier Blin <oblin@mandriva.com> 1.3.30-2mdv2007.1
+ Revision: 111118
- handle Should-Start/Should-Stop tags (#28026)
- fix priority when adding a LSB service required by another LSB service (#22019)

* Sat Jan 20 2007 Olivier Blin <oblin@mandriva.com> 1.3.30-1mdv2007.1
+ Revision: 111065
- 1.3.30
- bunzip2 patches
- Import chkconfig

* Sat Sep 16 2006 Olivier Blin <blino@mandriva.com> 1.3.25-2mdv2007.0
- Patch13: don't incorrectly enable disabled services on --add
  (thanks to Andreas for the help, #23104)
  from https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=182729

* Mon Jan 09 2006 Olivier Blin <oblin@mandriva.com> 1.3.25-1mdk
- 1.3.25
- rediff Patch6
- drop hybrid LSB support in Patch11 (mostly merged upstream)
- simplify requirements check on delete in Patch11 (and use runlevel)
- check for requirements when on add in Patch11

* Sat Dec 31 2005 Mandriva Linux Team <http://www.mandrivaexpert.com/> 1.3.20-5mdk
- Rebuild

* Sat Jul 02 2005 Stew Benedict <sbenedict@mandriva.com> 1.3.20-4mdk
- redo P11 to handle hybrid scripts like shorewall, pptp, vmware (#16658)

* Fri Jul 01 2005 Frederic Lepied <flepied@mandriva.com> 1.3.20-3mdk
- fixed french transalation to aligned status in chkconfig --list (bug #6062).

* Wed Jun 29 2005 Stew Benedict <sbenedict@mandriva.com> 1.3.20-2mdk
- P11 - chkconfig doesn't handle LSB style script dependencies correctly

* Mon Jun 13 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 1.3.20-1mdk
- 1.3.20
- regenerate P6
- drop P9 & P11 (fixed upstream)

* Fri Feb 11 2005 Frederic Lepied <flepied@mandrakesoft.com> 1.3.13-3mdk
- really fix LSB logic

* Fri Feb 04 2005 Frederic Lepied <flepied@mandrakesoft.com> 1.3.13-2mdk
- fix LSB logic

* Thu Jan 20 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.3.13-1mdk
- 1.3.13
- do parallell build
- fix summary-ended-with-dot

* Fri Nov 12 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.3.11.1-1mdk
- 1.3.11.1
- drop P11 (merged upstream)

* Thu Jul 15 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.3.11-1mdk
- 1.3.11
- update no translation (P11)
- regenerate P6, P9 & P11

* Mon Jan 26 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.3.8-5mdk
- fix unpackaged files

